@@ -13,8 +13,8 @@ from contextlib import redirect_stdout
 import json
 import re
 from bs4 import BeautifulSoup
-from tools.path_harvest import PathColector
-from tools.silencer import Silencer
+from ChiMera.tools.path_harvest import PathColector
+from ChiMera.tools.silencer import Silencer
 import os.path
 import subprocess
 import sys
